@@ -42,8 +42,8 @@ def get_stock_market(symbol='', string=False):
 
     market = None
 
-    if symbol.startswith(('sh', 'sz')):
-        market = symbol[:2]
+    if symbol.startswith(('sh', 'sz', 'SH', 'SZ')):
+        market = symbol[:2].lower()
 
     elif symbol.startswith(('50', '51', '60', '68', '90', '110', '113', '132', '204')):
         market = 'sh'
